==> jakarta-persistence-tck-2.2.0.zip: persistence-tck/src/com/sun/ts/tests/jpa/core/relationship/bidirmanyxmany/BiDirMXMProject.java <==
/*
 * Copyright (c) 2009, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.ts.tests.jpa.core.relationship.bidirmanyxmany;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.ManyToMany;
import java.io.Serializable;
import java.util.Collection;

/**
 *
 * @author Raja Perumal
 */
@Entity
public class BiDirMXMProject implements Serializable {

  private static final long serialVersionUID = 1L;

  @Id
  private Long id;

  private String name;

  private Float budget;

  @ManyToMany(mappedBy = "projects")
  private Collection<BiDirMXMPerson> biDirMXMPersons;

  public Collection<BiDirMXMPerson> getBiDirMXMPersons() {
    return biDirMXMPersons;
  }

  public void setBiDirMXMPersons(Collection<BiDirMXMPerson> biDirMXMPersons) {
    this.biDirMXMPersons = biDirMXMPersons;
  }

  public BiDirMXMProject() {
  }

  public Float getBudget() {
    return budget;
  }

  public void setBudget(Float budget) {
    this.budget = budget;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public BiDirMXMProject(long l, String string, Float aFloat) {
    this.id = l;
    this.name = string;
    this.budget = aFloat;
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  @Override
  public int hashCode() {
    int hash = 0;
    hash += (id != null ? id.hashCode() : 0);
    return hash;
  }

  @Override
  public boolean equals(Object object) {
    if (!(object instanceof BiDirMXMProject)) {
      return false;
    }
    BiDirMXMProject other = (BiDirMXMProject) object;
    if ((this.id == null && other.id != null)
        || (this.id != null && !this.id.equals(other.id))) {
      return false;
    }
    return true;
  }

  @Override
  public String toString() {
    return "bidirmanyxmany.BiDirMXMProject[id=" + id + "]";
  }
}

==> jakarta-persistence-tck-3.0.0.zip: persistence-tck/src/com/sun/ts/tests/jpa/core/relationship/bidirmanyxmany/BiDirMXMProject.java <==
/*
 * Copyright (c) 2009, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.ts.tests.jpa.core.relationship.bidirmanyxmany;

import jakarta.persistence.Entity;
import jakarta.persistence.Id;
import jakarta.persistence.ManyToMany;
import java.io.Serializable;
import java.util.Collection;

/**
 *
 * @author Raja Perumal
 */
@Entity
public class BiDirMXMProject implements Serializable {

  private static final long serialVersionUID = 1L;

  @Id
  private Long id;

  private String name;

  private Float budget;

  @ManyToMany(mappedBy = "projects")
  private Collection<BiDirMXMPerson> biDirMXMPersons;

  public Collection<BiDirMXMPerson> getBiDirMXMPersons() {
    return biDirMXMPersons;
  }

  public void setBiDirMXMPersons(Collection<BiDirMXMPerson> biDirMXMPersons) {
    this.biDirMXMPersons = biDirMXMPersons;
  }

  public BiDirMXMProject() {
  }

  public Float getBudget() {
    return budget;
  }

  public void setBudget(Float budget) {
    this.budget = budget;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public BiDirMXMProject(long l, String string, Float aFloat) {
    this.id = l;
    this.name = string;
    this.budget = aFloat;
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  @Override
  public int hashCode() {
    int hash = 0;
    hash += (id != null ? id.hashCode() : 0);
    return hash;
  }

  @Override
  public boolean equals(Object object) {
    if (!(object instanceof BiDirMXMProject)) {
      return false;
    }
    BiDirMXMProject other = (BiDirMXMProject) object;
    if ((this.id == null && other.id != null)
        || (this.id != null && !this.id.equals(other.id))) {
      return false;
    }
    return true;
  }

  @Override
  public String toString() {
    return "bidirmanyxmany.BiDirMXMProject[id=" + id + "]";
  }
}
